@@ -12,6 +12,8 @@ pub const ANTHROPIC_API_URL: &'static str = "https://api.anthropic.com";
 #[derive(Clone, Debug, Default, Serialize, Deserialize, PartialEq, EnumIter)]
 pub enum Model {
     #[default]
+    #[serde(alias = "claude-3-5-sonnet", rename = "claude-3-5-sonnet-20240620")]
+    Claude3_5Sonnet,
     #[serde(alias = "claude-3-opus", rename = "claude-3-opus-20240229")]
     Claude3Opus,
     #[serde(alias = "claude-3-sonnet", rename = "claude-3-sonnet-20240229")]
@@ -22,7 +24,9 @@ pub enum Model {
 
 impl Model {
     pub fn from_id(id: &str) -> Result<Self> {
-        if id.starts_with("claude-3-opus") {
+        if id.starts_with("claude-3-5-sonnet") {
+            Ok(Self::Claude3_5Sonnet)
+        } else if id.starts_with("claude-3-opus") {
             Ok(Self::Claude3Opus)
         } else if id.starts_with("claude-3-sonnet") {
             Ok(Self::Claude3Sonnet)
@@ -35,6 +39,7 @@ impl Model {
 
     pub fn id(&self) -> &'static str {
         match self {
+            Model::Claude3_5Sonnet => "claude-3-5-sonnet-20240620",
             Model::Claude3Opus => "claude-3-opus-20240229",
             Model::Claude3Sonnet => "claude-3-sonnet-20240229",
             Model::Claude3Haiku => "claude-3-opus-20240307",
@@ -43,6 +48,7 @@ impl Model {
 
     pub fn display_name(&self) -> &'static str {
         match self {
+            Self::Claude3_5Sonnet => "Claude 3.5 Sonnet",
             Self::Claude3Opus => "Claude 3 Opus",
             Self::Claude3Sonnet => "Claude 3 Sonnet",
             Self::Claude3Haiku => "Claude 3 Haiku",
