@@ -76,6 +76,7 @@ fn main() {
             cx.open_window(options, |cx| {
                 cx.activate(false);
                 cx.new_view(|_cx| AnimationExample {})
-            });
+            })
+            .unwrap();
         });
 }
