@@ -2287,6 +2287,15 @@ impl Pixels {
     pub fn abs(&self) -> Self {
         Self(self.0.abs())
     }
+
+    /// Returns the f64 value of `Pixels`.
+    ///
+    /// # Returns
+    ///
+    /// A f64 value of the `Pixels`.
+    pub fn to_f64(self) -> f64 {
+        self.0 as f64
+    }
 }
 
 impl Mul<Pixels> for Pixels {
