@@ -2,8 +2,10 @@ mod client;
 mod display;
 mod event;
 mod window;
+mod xim_handler;
 
 pub(crate) use client::*;
 pub(crate) use display::*;
 pub(crate) use event::*;
 pub(crate) use window::*;
+pub(crate) use xim_handler::*;
