@@ -97,6 +97,9 @@ pub enum IconName {
     BellOff,
     BellRing,
     Bolt,
+    Book,
+    BookCopy,
+    BookPlus,
     CaseSensitive,
     Check,
     ChevronDown,
@@ -231,6 +234,9 @@ impl IconName {
             IconName::BellOff => "icons/bell_off.svg",
             IconName::BellRing => "icons/bell_ring.svg",
             IconName::Bolt => "icons/bolt.svg",
+            IconName::Book => "icons/book.svg",
+            IconName::BookCopy => "icons/book_copy.svg",
+            IconName::BookPlus => "icons/book_plus.svg",
             IconName::CaseSensitive => "icons/case_insensitive.svg",
             IconName::Check => "icons/check.svg",
             IconName::ChevronDown => "icons/chevron_down.svg",
